<?php
/**
 * VW Newspaper Theme Customizer
 *
 * @package VW Newspaper
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_newspaper_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_newspaper_custom_controls' );

function vw_newspaper_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_newspaper_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-newspaper' ),
	    'description' => __( 'Description of what this panel does.', 'vw-newspaper' ),
	) );

	$wp_customize->add_section( 'vw_newspaper_left_right', array(
    	'title'      => __( 'General Settings', 'vw-newspaper' ),
		'priority'   => 30,
		'panel' => 'vw_newspaper_panel_id'
	) );

	$wp_customize->add_setting('vw_newspaper_width_option',array(
        'default' => __('Full Width','vw-newspaper'),
        'sanitize_callback' => 'vw_newspaper_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Newspaper_Image_Radio_Control($wp_customize, 'vw_newspaper_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-newspaper'),
        'description' => __('Here you can change the width layout of Website.','vw-newspaper'),
        'section' => 'vw_newspaper_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_newspaper_theme_options',array(
        'default' => __('Right Sidebar','vw-newspaper'),
        'sanitize_callback' => 'vw_newspaper_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_newspaper_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-newspaper'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-newspaper'),
        'section' => 'vw_newspaper_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-newspaper'),
            'Right Sidebar' => __('Right Sidebar','vw-newspaper'),
            'One Column' => __('One Column','vw-newspaper'),
            'Three Columns' => __('Three Columns','vw-newspaper'),
            'Four Columns' => __('Four Columns','vw-newspaper'),
            'Grid Layout' => __('Grid Layout','vw-newspaper')
        ),
	));

	$wp_customize->add_setting('vw_newspaper_page_layout',array(
        'default' => __('One Column','vw-newspaper'),
        'sanitize_callback' => 'vw_newspaper_sanitize_choices'
	));
	$wp_customize->add_control('vw_newspaper_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-newspaper'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-newspaper'),
        'section' => 'vw_newspaper_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-newspaper'),
            'Right Sidebar' => __('Right Sidebar','vw-newspaper'),
            'One Column' => __('One Column','vw-newspaper')
        ),
	) );
    
	//Todays Headline
	$wp_customize->add_section('vw_newspaper_headline_section',array(
		'title'	=> __('Todays Headline','vw-newspaper'),
		'description'=> __('This section is about todays heading.','vw-newspaper'),
		'panel' => 'vw_newspaper_panel_id',
	));	
	
	$wp_customize->add_setting('vw_newspaper_headline_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_newspaper_headline_title',array(
		'label'	=> __('Section Title','vw-newspaper'),
		'section'=> 'vw_newspaper_headline_section',
		'setting'=> 'vw_newspaper_headline_title',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
	if($i==0){
	$default = $category->slug;
	$i++;
	}
	$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_newspaper_headline_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_newspaper_sanitize_choices',
	));
	$wp_customize->add_control('vw_newspaper_headline_category',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display Latest Post','vw-newspaper'),
		'section' => 'vw_newspaper_headline_section',
	));

	$wp_customize->add_setting( 'vw_newspaper_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_newspaper_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Newspaper_Toggle_Switch_Custom_Control( $wp_customize, 'vw_newspaper_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-newspaper' ),
          'section' => 'vw_newspaper_headline_section'
    )));

	//Our Blog Category section
  	$wp_customize->add_section('vw_newspaper_category_section',array(
	    'title' => __('Category Section','vw-newspaper'),
	    'description' => '',
	    'priority'  => null,
	    'panel' => 'vw_newspaper_panel_id',
	)); 

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post1[]= 'select';
	foreach($categories as $category){
	if($i==0){
	$default = $category->slug;
	$i++;
	}
	$cat_post1[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_newspaper_category',array(
	    'default' => 'select',
	    'sanitize_callback' => 'vw_newspaper_sanitize_choices',
  	));

  	$wp_customize->add_control('vw_newspaper_category',array(
	    'type'    => 'select',
	    'choices' => $cat_post1,
	    'label' => __('Select Category to display Latest Post','vw-newspaper'),
	    'section' => 'vw_newspaper_category_section',
	));

	//Blog Post
	$wp_customize->add_section('vw_newspaper_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-newspaper'),
		'panel' => 'vw_newspaper_panel_id',
	));	

	$wp_customize->add_setting( 'vw_newspaper_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_newspaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Newspaper_Toggle_Switch_Custom_Control( $wp_customize, 'vw_newspaper_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-newspaper' ),
        'section' => 'vw_newspaper_blog_post'
    )));

    $wp_customize->add_setting( 'vw_newspaper_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_newspaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Newspaper_Toggle_Switch_Custom_Control( $wp_customize, 'vw_newspaper_toggle_author',array(
		'label' => esc_html__( 'Author','vw-newspaper' ),
		'section' => 'vw_newspaper_blog_post'
    )));

    $wp_customize->add_setting( 'vw_newspaper_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_newspaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Newspaper_Toggle_Switch_Custom_Control( $wp_customize, 'vw_newspaper_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-newspaper' ),
		'section' => 'vw_newspaper_blog_post'
    )));

    $wp_customize->add_setting( 'vw_newspaper_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_newspaper_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-newspaper' ),
		'section'     => 'vw_newspaper_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_newspaper_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Craetion
	$wp_customize->add_section( 'vw_newspaper_content_section' , array(
    	'title' => __( 'Customize Home Page', 'vw-newspaper' ),
		'priority' => null,
		'panel' => 'vw_newspaper_panel_id'
	) );

	$wp_customize->add_setting('vw_newspaper_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Newspaper_Content_Creation( $wp_customize, 'vw_newspaper_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-newspaper' ),
		),
		'section' => 'vw_newspaper_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-newspaper' ),
	) ) );


	//Footer Text
	$wp_customize->add_section('vw_newspaper_footer',array(
		'title'	=> __('Footer','vw-newspaper'),
		'description'=> __('This section will appear in the footer','vw-newspaper'),
		'panel' => 'vw_newspaper_panel_id',
	));	
	
	$wp_customize->add_setting('vw_newspaper_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_newspaper_footer_text',array(
		'label'	=> __('Copyright Text','vw-newspaper'),
		'section'=> 'vw_newspaper_footer',
		'setting'=> 'vw_newspaper_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'vw_newspaper_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_newspaper_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Newspaper_Toggle_Switch_Custom_Control( $wp_customize, 'vw_newspaper_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-newspaper' ),
      	'section' => 'vw_newspaper_footer'
    )));

	$wp_customize->add_setting('vw_newspaper_scroll_top_alignment',array(
        'default' => __('Right','vw-newspaper'),
        'sanitize_callback' => 'vw_newspaper_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Newspaper_Image_Radio_Control($wp_customize, 'vw_newspaper_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-newspaper'),
        'section' => 'vw_newspaper_footer',
        'settings' => 'vw_newspaper_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_newspaper_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Newspaper_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Newspaper_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Newspaper_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW Newspaper Pro', 'vw-newspaper' ),
			'pro_text' => esc_html__( 'Upgrade Pro', 'vw-newspaper' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/newspaper-wordpress-theme/'),
		)));
	
		// Register sections.
		$manager->add_section(new VW_Newspaper_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-newspaper' ),
			'pro_text' => esc_html__( 'Docs', 'vw-newspaper' ),
			'pro_url'  => admin_url('themes.php?page=vw_newspaper_guide'),
		)));
	}
	

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-newspaper-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-newspaper-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Newspaper_Customize::get_instance();